#!/bin/bash
set -o errexit -o pipefail -o noclobber -o nounset

DEPENDENCY_TO_BUILD="all"
while [ $# -gt 0 ]; do
    case "$1" in
        --yaco-root)
            YACO_ROOT=$2
            ABSOLUTE_YACO_ROOT=$(readlink -f "${YACO_ROOT}")
            shift 2
            ;;
        --dependency)
            DEPENDENCY_TO_BUILD=$2
            shift 2
            ;;
        *)
            echo "Error: unknown argument '$1'. Call this script with --yaco-root and path to your yaco-root"
            exit 1
            ;;
    esac
done

echo "Absolute path provided as the yaco root: $ABSOLUTE_YACO_ROOT"

COMPILER="mpich-gcc-13"
export CC="mpicc"
export FC="mpif90"
export CXX="mpicxx"
export MPI_LAUNCH="mpiexec"

THREADS=8
BUILD_PATH=$ABSOLUTE_YACO_ROOT/build/$COMPILER
INSTALL_PATH=$BUILD_PATH/install


# build dependencies for yaco
echo "=== Building yaco dependencies ==="
echo $DEPENDENCY_TO_BUILD
CC="${CC}" CXX="${CXX}" FC="${FC}" $ABSOLUTE_YACO_ROOT/scripts/setup/build-dependencies.sh -j $THREADS --dependency $DEPENDENCY_TO_BUILD --build_dir_name $COMPILER --prefix_path $INSTALL_PATH

# build yaco
echo "=== Building yaco ==="
cd "$BUILD_PATH"
CC="${CC}" CXX="${CXX}" FC="${FC}" cmake $ABSOLUTE_YACO_ROOT -DCMAKE_PREFIX_PATH=$INSTALL_PATH -DENABLE_NETCDF=OFF -DCMAKE_EXPORT_COMPILE_COMMANDS=ON -DCMAKE_BUILD_TYPE=Release
cmake --build . -j $THREADS
